clear all
set mem 1g
set more off

capture log close
log using "c:\EventStudy\bARC_Stata.log", append


use "C:\EventStudy\Input\Data.dta", clear


* --------- Setting Estimation Window ------------- *

bysort co_id: gen event_date = days_co if  event_id!= .

sort co_id
summ co_id
local tot_cos = `r(max)'
gen diff_est_window = .
gen est_window = .
forvalues i = 1/`tot_cos' {

	  summ event_date if co_id == `i' 
	  local event_date_co_id_`i' = r(mean)

	  summ est_window_length if co_id == `i' 
	  local est_window_length_co_id_`i' = r(mean)

	  summ est_window_endpointer if co_id == `i' 
	  local est_window_endpointer_co_id_`i' = r(mean) + 1

	  replace diff_est_window = `event_date_co_id_`i'' + `est_window_endpointer_co_id_`i'' - days_co if co_id == `i' 

	  replace est_window = 1 if co_id == `i' & diff_est_window <= `est_window_length_co_id_`i'' 
		 
	  replace est_window = . if co_id == `i' & diff_est_window <= 0

	  }


* --------- Setting Event Window ------------- *

gen diff_evnt_window = .
gen evnt_window = .
forvalues i = 1/`tot_cos' {

	  replace diff_evnt_window = `event_date_co_id_`i'' - days_co if co_id == `i' 

	  replace evnt_window = 1 if co_id == `i' & abs(diff_evnt_window) <= abs(`est_window_endpointer_co_id_`i'')

	  }

	        
* --------- Estimating Normal Performance ------------- *

gen predicted_return = .
forvalues i = 1/`tot_cos' {

	  reg co_ret mkt_ret if co_id == `i' & est_window == 1
	  local rmse_co_id_`i' = `e(rmse)'
	  predict p if co_id == `i' & evnt_window == 1
	  replace predicted_return = p if co_id == `i' & evnt_window == 1
	  drop p

	  }


* --------- Calculating Abnormal Returns ------------- *

gen abnormal_return = .
forvalues i = 1/`tot_cos' {
	  replace abnormal_return = co_ret - predicted_return if co_id == `i' & evnt_window == 1
	  }


* --------- Testing for Significance ------------- *

gen t_value = .
forvalues i = 1/`tot_cos' {
	  replace t_value = abnormal_return/`rmse_co_id_`i'' if co_id == `i' & evnt_window == 1
	  }


save "C:\EventStudy\Output\Results.dta", replace



log close


